@@ -57,8 +57,10 @@ const (
 	TenvQuiet       = tenvPrefix + quiet
 	TenvRemoteConf  = tenvPrefix + "REMOTE_CONF"
 	TenvRootPath    = tenvPrefix + rootPath
+	TenvLockPath    = tenvPrefix + "LOCK_PATH"
 	TenvSkipLastUse = tenvPrefix + "SKIP_LAST_USE"
 	TenvToken       = tenvPrefix + token
+	TenvValidation  = tenvPrefix + "VALIDATION"
 
 	TfenvPrefix          = "TFENV_"
 	TfenvTerraformPrefix = TfenvPrefix + "TERRAFORM_"
